[−][src]Struct sp_trie::Recorder
Various re-exports from the trie-db crate.
Records trie nodes as they pass it.
Implementations
impl<HO> Recorder<HO> where
HO: Copy, [src][−]
HO: Copy,
Various re-exports from the trie-db crate.
pub fn new() -> Recorder<HO>[src][−]
Create a new Recorder which records all given nodes.
pub fn with_depth(depth: u32) -> Recorder<HO>[src][−]
Create a Recorder which only records nodes beyond a given depth.
pub fn record(&mut self, hash: &HO, data: &[u8], depth: u32)[src][−]
Record a visited node, given its hash, data, and depth.
pub fn drain(&mut self) -> Vec<Record<HO>>[src][−]
Drain all visited records.